instrumenttools.ContraltoVoice
==============================

.. abjad-lineage:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice

.. autoclass:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ContraltoVoice.ContraltoVoice.ContraltoVoice.__repr__
   :noindex:
